==> jc-1.4.0.tar.gz: soot/jimple/internal/JNegExpr.h <==
// public class soot.jimple.internal.JNegExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr
// @dep_class 13235dcdbd3d09d4 soot_jimple_internal_JNegExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNegExpr

#include "soot/jimple/internal/AbstractNegExpr.h"

#ifndef _JC_soot_jimple_internal_JNegExpr_H_
#define _JC_soot_jimple_internal_JNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNegExpr$sub_refs	_jc_soot_jimple_internal_JNegExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNegExpr$sub_nonrefs	_jc_soot_jimple_internal_JNegExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNegExpr$refs	_jc_soot_jimple_internal_JNegExpr$refs;
typedef struct _jc_soot_jimple_internal_JNegExpr$nonrefs	_jc_soot_jimple_internal_JNegExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNegExpr$object	_jc_soot_jimple_internal_JNegExpr$object;

typedef const struct _jc_soot_jimple_internal_JNegExpr$vmethods	_jc_soot_jimple_internal_JNegExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNegExpr$vtable	_jc_soot_jimple_internal_JNegExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNegExpr$vtype	_jc_soot_jimple_internal_JNegExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNegExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *);
extern void _jc_soot_jimple_internal_JNegExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNegExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JNegExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNegExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
	_jc_soot_jimple_internal_JNegExpr$vmethods	soot_jimple_internal_JNegExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNegExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNegExpr$refs {
    _jc_soot_jimple_internal_JNegExpr$sub_refs	soot_jimple_internal_JNegExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_JNegExpr$sub_nonrefs	soot_jimple_internal_JNegExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNegExpr$object {
	_jc_soot_jimple_internal_JNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNegExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNegExpr$vtype _jc_soot_jimple_internal_JNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNegExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNegExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JNegExpr.h <==
// public class soot.jimple.internal.JNegExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr
// @dep_class 13235dcdbd3d09d4 soot_jimple_internal_JNegExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNegExpr

#include "soot/jimple/internal/AbstractNegExpr.h"

#ifndef _JC_soot_jimple_internal_JNegExpr_H_
#define _JC_soot_jimple_internal_JNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNegExpr$sub_refs	_jc_soot_jimple_internal_JNegExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNegExpr$sub_nonrefs	_jc_soot_jimple_internal_JNegExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNegExpr$refs	_jc_soot_jimple_internal_JNegExpr$refs;
typedef struct _jc_soot_jimple_internal_JNegExpr$nonrefs	_jc_soot_jimple_internal_JNegExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNegExpr$object	_jc_soot_jimple_internal_JNegExpr$object;

typedef const struct _jc_soot_jimple_internal_JNegExpr$vmethods	_jc_soot_jimple_internal_JNegExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNegExpr$vtable	_jc_soot_jimple_internal_JNegExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNegExpr$vtype	_jc_soot_jimple_internal_JNegExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNegExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JNegExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNegExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JNegExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNegExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JNegExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
	_jc_soot_jimple_internal_JNegExpr$vmethods	soot_jimple_internal_JNegExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNegExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNegExpr$refs {
    _jc_soot_jimple_internal_JNegExpr$sub_refs	soot_jimple_internal_JNegExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_JNegExpr$sub_nonrefs	soot_jimple_internal_JNegExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNegExpr$object {
	_jc_soot_jimple_internal_JNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNegExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNegExpr$vtype _jc_soot_jimple_internal_JNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNegExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNegExpr_H_ */
